/**
 * @file
 * JavaScript behaviors for Commerce Webform Order handlers.
 */

(function ($, Drupal, once) {

  'use strict';

  /**
   * Trigger other input field events.
   *
   * @param {boolean} show
   *   TRUE will display the text field. FALSE with hide and clear the text
   *   field.
   * @param {object} $element
   *   The input (text) field to be toggled.
   * @param {string} effect
   *   Effect.
   */
  function toggleOther(show, $element, effect) {
    var $input = $element.find('input');

    if (show) {
      var value = $input.data('webform-value');
      if (typeof value !== 'undefined') {
        // Trigger change and autocomplete close event.
        $input.trigger('change')
          .trigger('autocompleteclose');
      }
    }
    else {
      // Trigger change event.
      $input.trigger('change');
    }
  }

  /**
   * Attach handlers to select other elements.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.commerceWebformOrderHandlerCommerceWebformOrder = {
    attach: function (context) {
      $(once('commerce-webform-order--handler', '.commerce-webform-order--purchasable-entity', context)).each(function () {
        var $element = $(this);

        var $select = $element.find('select');
        var $input = $element.find('.js-webform-select-other-input');

        $select.on('change', function () {
          var isOtherSelected = $select
            .find('option[value="_other_"]')
            .is(':selected');
          toggleOther(isOtherSelected, $input);
        });

        var isOtherSelected = $select
          .find('option[value="_other_"]')
          .is(':selected');
        toggleOther(isOtherSelected, $input, false);
      });
    }
  };

})(jQuery, Drupal, once);
